@@ -42,7 +42,9 @@ class ErrorInfo(Error):
     ```
     """
 
+    name = "no-default-or"
     code = 143
+    categories = ["logical", "readability"]
 
 
 def check(node: OpExpr, errors: list[Error]) -> None:
@@ -52,7 +54,6 @@ def check(node: OpExpr, errors: list[Error]) -> None:
                 case CallExpr(
                     callee=NameExpr(name=name, fullname=fullname), args=[]
                 ):
-                    fullname = fullname
                     expr = f"{name}()"
 
                 case ListExpr(items=[]):
