@@ -1,9 +1,9 @@
 import re
+from collections.abc import Sequence
 from functools import cache
 from importlib import metadata
 from io import StringIO
 from pathlib import Path
-from typing import Sequence
 
 from mypy.build import build
 from mypy.errors import CompileError
@@ -66,9 +66,8 @@ def get_source_lines(filepath: str) -> list[str]:
     return Path(filepath).read_text("utf8").splitlines()
 
 
-def ignored_via_comment(error: Error | str) -> bool:
-    if isinstance(error, str) or not error.filename:
-        return False
+def is_ignored_via_comment(error: Error) -> bool:
+    assert error.filename
 
     line = get_source_lines(error.filename)[error.line - 1]
 
@@ -82,6 +81,39 @@ def ignored_via_comment(error: Error | str) -> bool:
     return False
 
 
+def is_ignored_via_amend(error: Error, settings: Settings) -> bool:
+    assert error.filename
+
+    path = Path(error.filename).resolve()
+    error_code = ErrorCode.from_error(type(error))
+    config_root = (
+        Path(settings.config_file).parent if settings.config_file else Path()
+    )
+
+    for ignore in settings.ignore:
+        if ignore.path:
+            ignore_path = (config_root / ignore.path).resolve()
+
+            if path.is_relative_to(ignore_path):
+                if isinstance(ignore, ErrorCode):
+                    return str(ignore) == str(error_code)
+
+                return ignore.value in error.categories
+
+    return False
+
+
+def should_ignore_error(error: Error | str, settings: Settings) -> bool:
+    if isinstance(error, str):
+        return False
+
+    return (
+        not error.filename
+        or is_ignored_via_comment(error)
+        or is_ignored_via_amend(error, settings)
+    )
+
+
 def run_refurb(settings: Settings) -> Sequence[Error | str]:
     stdout = StringIO()
     stderr = StringIO()
@@ -93,6 +125,7 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
             "--exclude",
             ".*\\.pyi",
             "--explicit-package-bases",
+            "--namespace-packages",
         ]
 
         files, opt = process_options(args, stdout=stdout, stderr=stderr)
@@ -111,9 +144,7 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
     opt.cache_fine_grained = True
     opt.allow_redefinition = True
     opt.local_partial_types = True
-
-    if settings.python_version:
-        opt.python_version = settings.python_version  # pragma: no cover
+    opt.python_version = settings.python_version
 
     try:
         result = build(files, options=opt)
@@ -139,7 +170,11 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
             errors += visitor.errors
 
     return sorted(
-        [error for error in errors if not ignored_via_comment(error)],
+        [
+            error
+            for error in errors
+            if not should_ignore_error(error, settings)
+        ],
         key=sort_errors,
     )
 
@@ -160,7 +195,7 @@ def sort_errors(
 
 
 def format_errors(errors: Sequence[Error | str], quiet: bool) -> str:
-    done = "\n".join((str(error) for error in errors))
+    done = "\n".join(str(error) for error in errors)
 
     if not quiet and any(isinstance(error, Error) for error in errors):
         done += "\n\nRun `refurb --explain ERR` to further explain an error. Use `--quiet` to silence this message"
