@@ -2,9 +2,10 @@ from __future__ import annotations
 
 import re
 import sys
-from dataclasses import dataclass, field
+from collections.abc import Iterator
+from dataclasses import dataclass, field, replace
 from pathlib import Path
-from typing import Iterator
+from typing import Any
 
 if sys.version_info >= (3, 11):
     import tomllib  # pragma: no cover
@@ -14,6 +15,10 @@ else:
 from .error import ErrorCategory, ErrorClassifier, ErrorCode
 
 
+def get_python_version() -> tuple[int, int]:
+    return sys.version_info[:2]
+
+
 @dataclass
 class Settings:
     files: list[str] = field(default_factory=list)
@@ -30,7 +35,7 @@ class Settings:
     enable_all: bool = False
     disable_all: bool = False
     config_file: str | None = None
-    python_version: tuple[int, int] | None = None
+    python_version: tuple[int, int] = get_python_version()
     mypy_args: list[str] = field(default_factory=list)
 
     def __post_init__(self) -> None:
@@ -68,7 +73,7 @@ class Settings:
             enable_all=old.enable_all or new.enable_all,
             quiet=old.quiet or new.quiet,
             config_file=old.config_file or new.config_file,
-            python_version=old.python_version or new.python_version,
+            python_version=new.python_version,
             mypy_args=new.mypy_args or old.mypy_args,
         )
 
@@ -102,43 +107,74 @@ def parse_python_version(version: str) -> tuple[int, int]:
     raise ValueError("refurb: version must be in form `x.y`")
 
 
+def parse_amend_error(err: str, path: Path) -> ErrorClassifier:
+    classifier = parse_error_classifier(err)
+
+    return replace(classifier, path=path)
+
+
+def parse_amendment(  # type: ignore
+    amendment: dict[str, Any]
+) -> set[ErrorClassifier]:
+    match amendment:
+        case {"path": str(path), "ignore": list(ignored), **extra}:
+            if extra:
+                raise ValueError(
+                    'refurb: only "path" and "ignore" fields are supported'
+                )
+
+            return {
+                parse_amend_error(str(error), Path(path)) for error in ignored
+            }
+
+    raise ValueError(
+        'refurb: "path" or "ignore" fields are missing or malformed'
+    )
+
+
 def parse_config_file(contents: str) -> Settings:
-    config = tomllib.loads(contents)
+    tool = tomllib.loads(contents).get("tool")
 
-    if tool := config.get("tool"):
-        if config := tool.get("refurb"):
-            ignore = {
-                parse_error_classifier(str(x))
-                for x in config.get("ignore", [])
-            }
+    if not tool:
+        return Settings()
 
-            enable = {
-                parse_error_classifier(str(x))
-                for x in config.get("enable", [])
-            }
+    config = tool.get("refurb")
 
-            disable = {
-                parse_error_classifier(str(x))
-                for x in config.get("disable", [])
-            }
+    if not config:
+        return Settings()
 
-            version = config.get("python_version")
-            python_version = parse_python_version(version) if version else None
-            mypy_args = [str(x) for x in config.get("mypy_args", [])]
+    ignore = {parse_error_classifier(str(x)) for x in config.get("ignore", [])}
+    enable = {parse_error_classifier(str(x)) for x in config.get("enable", [])}
 
-            return Settings(
-                ignore=ignore,
-                enable=enable - disable,
-                disable=disable,
-                load=config.get("load", []),
-                quiet=config.get("quiet", False),
-                disable_all=config.get("disable_all", False),
-                enable_all=config.get("enable_all", False),
-                python_version=python_version,
-                mypy_args=mypy_args,
-            )
+    disable = {
+        parse_error_classifier(str(x)) for x in config.get("disable", [])
+    }
 
-    return Settings()
+    version = config.get("python_version")
+    python_version = (
+        parse_python_version(version) if version else get_python_version()
+    )
+    mypy_args = [str(arg) for arg in config.get("mypy_args", [])]
+
+    amendments: list[dict[str, Any]] = config.get("amend", [])  # type: ignore
+
+    if not isinstance(amendments, list):
+        raise ValueError('refurb: "amend" field(s) must be a TOML table')
+
+    for amendment in amendments:
+        ignore.update(parse_amendment(amendment))
+
+    return Settings(
+        ignore=ignore,
+        enable=enable - disable,
+        disable=disable,
+        load=config.get("load", []),
+        quiet=config.get("quiet", False),
+        disable_all=config.get("disable_all", False),
+        enable_all=config.get("enable_all", False),
+        python_version=python_version,
+        mypy_args=mypy_args,
+    )
 
 
 def parse_command_line_args(args: list[str]) -> Settings:
